/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * Created on 13.06.2003
 */
package at.spardat.xma.plugins.dummy;

import java.util.Map;

import javax.security.auth.Subject;
import javax.security.auth.callback.*;
import javax.security.auth.login.LoginException;
import javax.security.auth.spi.LoginModule;


/**
 * Dummy implementation of a cliend side authentication plugin (JAAS LoginModule).
 * This implementation takes no username or password. It allways logs in as
 * user "Dummy" in the mandant "188".
 * The user is implemented as {@link DummyContext}.
 *
 * @author s2877
 */
public class DummyLoginModule implements LoginModule {
    CallbackHandler handler;
    Subject subject;
    DummyContext context;
    char[] credential;


    /**
     * aborts the login process
     * the {@link DummyContext} is thrown away
     * @return allways true
     * @throws LoginExcption is never thrown
     */
    public boolean abort() throws LoginException {
        context=null;
        credential=null;
        return true;
    }

    /**
     * commits the login process
     * the {@link DummyContext} is set into the subject.
     * @return allways true
     * @throws LoginExcption is never thrown
     */
    public boolean commit() throws LoginException {
        subject.getPrincipals().add(context);
        subject.getPrivateCredentials().add(credential);
        return true;
    }

    /**
     * initialzes the login module.
     * subject and handler are stored.
     * @param subject the subject to store the user data
     * @param handler ignored
     * @param sharedState ignored
     * @param options ignored
     */
    public void initialize(Subject subject, CallbackHandler handler, Map sharedState, Map options) {
        this.subject=subject;
        this.handler=handler;
    }

    /**
     * do a login.
     * creates the {@link DummyContext}.
     * @return allways true
     * @throws LoginExcption is never thrown
     */
    public boolean login() throws LoginException {
        context=new DummyContext();
        context.setName("Dummy");
        context.setMandant("188");
        credential="secret".toCharArray();
        return true;
    }

    /**
     * do a logout.
     * the {@link DummyContext} is removed from the subject.
     * @return allways true
     * @throws LoginExcption is never thrown
     */
    public boolean logout() throws LoginException {
        subject.getPrincipals().remove(context);
        subject.getPrivateCredentials().remove(credential);
        return true;
    }

}
